@@ -9,7 +9,6 @@ import pathlib
 import platform
 import psutil
 import tabulate
-import tempfile
 import termcolor
 import traceback
 import urllib
@@ -83,7 +82,6 @@ PROGRESS_SAMPLES=10 PROGRESS_OUTPUT_INDENT=2 python benchmark.py
     machine = {"id": machine_id, "name": machine_name, "specs": machine_specs}
 
     def inner(main):
-
         output = None
         if output_path.exists():
             with open(output_path, "r") as output_file:
@@ -129,16 +127,16 @@ PROGRESS_SAMPLES=10 PROGRESS_OUTPUT_INDENT=2 python benchmark.py
                 print(termcolor.colored(f"{'-' * len(title)}", "cyan"))
                 try:
                     class Subprocess:
-                        def __call__(self, output, parameters):
+                        def __call__(self, channel, parameters):
                             main(**parameters)
-                            with open(output, "w") as f:
-                                json.dump([METRICS, MEASUREMENTS, ALERTS], f)
+                            channel.put([METRICS, MEASUREMENTS, ALERTS])
+
+                    channel = multiprocessing.Queue()
 
-                    channel = tempfile.NamedTemporaryFile()
                     process = multiprocessing.Process(
                         name="(Sampler)",
                         target=Subprocess(),
-                        args=(channel.name, parameters),
+                        args=(channel, parameters),
                     )
 
                     try:
@@ -152,16 +150,12 @@ PROGRESS_SAMPLES=10 PROGRESS_OUTPUT_INDENT=2 python benchmark.py
                         exitcode = 1
 
                     if exitcode != 0:
-                        channel.close()
                         target["working"] = False
                         if "measurements" in target:
                             del target["measurements"]
                         break
 
-                    with open(channel.name, "r") as f:
-                        new_metrics, new_measurements, new_alerts = json.load(f)
-
-                    channel.close()
+                    new_metrics, new_measurements, new_alerts = channel.get()
 
                     METRICS.clear()
                     for key, value in new_metrics.items():
